@@ -15,6 +15,7 @@
 """Base class for all raspbian devices."""
 import re
 import time
+from typing import Callable, List
 
 from gazoo_device import config
 from gazoo_device import console_config
@@ -152,7 +153,7 @@ class RaspbianDevice(auxiliary_device.AuxiliaryDevice):
         self.switchboard.get_line_identifier())
 
   @decorators.PersistentProperty
-  def health_checks(self):
+  def health_checks(self) -> List[Callable[[], None]]:
     """Returns list of methods to execute as health checks."""
     return [
         self.check_device_connected, self.check_create_switchboard,
