@@ -14,6 +14,8 @@
 
 """Interface for a Matter On/Off Plug-in Unit endpoint."""
 import abc
+from gazoo_device.capabilities.matter_clusters.interfaces import level_control_base
+from gazoo_device.capabilities.matter_clusters.interfaces import on_off_base
 from gazoo_device.capabilities.matter_endpoints.interfaces import endpoint_base
 
 
@@ -24,12 +26,12 @@ class OnOffPluginUnitBase(endpoint_base.EndpointBase, metaclass=abc.ABCMeta):
 
   @property
   @abc.abstractmethod
-  def on_off(self):
+  def on_off(self) -> on_off_base.OnOffClusterBase:
     """Required cluster: ZCL on_off cluster."""
 
   @property
   @abc.abstractmethod
-  def level(self):
+  def level(self) -> level_control_base.LevelControlClusterBase:
     """Optional cluster: ZCL level cluster."""
 
   # TODO(b/209362086) Add the below clusters
