@@ -22,14 +22,16 @@ A OnOff light enpoint houses an instance of On/Off Light Matter device type with
 the following defined clusters on this endpoint:
 
 The required clusters for this endpoint: Scenes, OnOff and Groups.
-The optional clusters for this endpoint: Level and Occupancy.
+The optional clusters for this endpoint: Level and OccupancySensing.
 """
 from typing import Union
 
 from gazoo_device import decorators
 from gazoo_device.capabilities import matter_enums
+from gazoo_device.capabilities.matter_clusters import level_control_chip_tool
 from gazoo_device.capabilities.matter_clusters import level_control_pw_rpc
-from gazoo_device.capabilities.matter_clusters import occupancy_pw_rpc
+from gazoo_device.capabilities.matter_clusters import occupancy_sensing_chip_tool
+from gazoo_device.capabilities.matter_clusters import occupancy_sensing_pw_rpc
 from gazoo_device.capabilities.matter_clusters import on_off_chip_tool
 from gazoo_device.capabilities.matter_clusters import on_off_pw_rpc
 from gazoo_device.capabilities.matter_endpoints.interfaces import on_off_light_base
@@ -38,16 +40,6 @@ from gazoo_device.capabilities.matter_endpoints.interfaces import on_off_light_b
 class OnOffLightEndpoint(on_off_light_base.OnOffLightBase):
   """Matter OnOff light endpoint."""
 
-  @decorators.CapabilityDecorator(level_control_pw_rpc.LevelControlClusterPwRpc)
-  def level(self) -> level_control_pw_rpc.LevelControlClusterPwRpc:
-    """Matter Level Control cluster instance."""
-    return self.cluster_lazy_init(matter_enums.LevelControlCluster.ID)
-
-  @decorators.CapabilityDecorator(occupancy_pw_rpc.OccupancyClusterPwRpc)
-  def occupancy(self) -> occupancy_pw_rpc.OccupancyClusterPwRpc:
-    """Matter Occupancy cluster instance."""
-    return self.cluster_lazy_init(matter_enums.OccupancySensingCluster.ID)
-
   @decorators.CapabilityDecorator(
       [on_off_chip_tool.OnOffClusterChipTool, on_off_pw_rpc.OnOffClusterPwRpc])
   def on_off(
@@ -57,6 +49,28 @@ class OnOffLightEndpoint(on_off_light_base.OnOffLightBase):
     """Matter OnOff cluster instance."""
     return self.cluster_lazy_init(matter_enums.OnOffCluster.ID)
 
+  @decorators.CapabilityDecorator([
+      level_control_chip_tool.LevelControlClusterChipTool,
+      level_control_pw_rpc.LevelControlClusterPwRpc
+  ])
+  def level(
+      self
+  ) -> Union[level_control_chip_tool.LevelControlClusterChipTool,
+             level_control_pw_rpc.LevelControlClusterPwRpc]:
+    """Matter Level Control cluster instance."""
+    return self.cluster_lazy_init(matter_enums.LevelControlCluster.ID)
+
+  @decorators.CapabilityDecorator([
+      occupancy_sensing_chip_tool.OccupancySensingClusterChipTool,
+      occupancy_sensing_pw_rpc.OccupancySensingClusterPwRpc
+  ])
+  def occupancy_sensing(
+      self
+  ) -> Union[occupancy_sensing_chip_tool.OccupancySensingClusterChipTool,
+             occupancy_sensing_pw_rpc.OccupancySensingClusterPwRpc]:
+    """Matter Occupancy cluster instance."""
+    return self.cluster_lazy_init(matter_enums.OccupancySensingCluster.ID)
+
   # TODO(b/209362086) Add the below clusters
   # def scenes(self):
   #   """Matter Scenes cluster instance."""
